==> esper-6.0.0-sources.jar: com/espertech/esper/epl/agg/aggregator/AggregatorAvgBigDecimalFilter.java <==
/*
 ***************************************************************************************
 *  Copyright (C) 2006 EsperTech, Inc. All rights reserved.                            *
 *  http://www.espertech.com/esper                                                     *
 *  http://www.espertech.com                                                           *
 *  ---------------------------------------------------------------------------------- *
 *  The software in this package is published under the terms of the GPL license       *
 *  a copy of which has been included with this distribution in the license.txt file.  *
 ***************************************************************************************
 */
package com.espertech.esper.epl.agg.aggregator;

import com.espertech.esper.epl.agg.service.AggregatorUtil;

import java.math.MathContext;

/**
 * Average that generates a BigDecimal numbers.
 */
public class AggregatorAvgBigDecimalFilter extends AggregatorAvgBigDecimal {
    public AggregatorAvgBigDecimalFilter(MathContext optionalMathContext) {
        super(optionalMathContext);
    }

    public void enter(Object parameters) {
        Object[] paramArray = (Object[]) parameters;
        if (!AggregatorUtil.checkFilter(paramArray)) {
            return;
        }
        super.enter(paramArray[0]);
    }

    public void leave(Object parameters) {
        Object[] paramArray = (Object[]) parameters;
        if (!AggregatorUtil.checkFilter(paramArray)) {
            return;
        }
        super.leave(paramArray[0]);
    }
}

==> esper-7.1.0-sources.jar: com/espertech/esper/epl/agg/aggregator/AggregatorAvgBigDecimalFilter.java <==
/*
 ***************************************************************************************
 *  Copyright (C) 2006 EsperTech, Inc. All rights reserved.                            *
 *  http://www.espertech.com/esper                                                     *
 *  http://www.espertech.com                                                           *
 *  ---------------------------------------------------------------------------------- *
 *  The software in this package is published under the terms of the GPL license       *
 *  a copy of which has been included with this distribution in the license.txt file.  *
 ***************************************************************************************
 */
package com.espertech.esper.epl.agg.aggregator;

import com.espertech.esper.epl.agg.service.common.AggregatorUtil;

import java.math.MathContext;

/**
 * Average that generates a BigDecimal numbers.
 */
public class AggregatorAvgBigDecimalFilter extends AggregatorAvgBigDecimal {
    public AggregatorAvgBigDecimalFilter(MathContext optionalMathContext) {
        super(optionalMathContext);
    }

    public void enter(Object parameters) {
        Object[] paramArray = (Object[]) parameters;
        if (!AggregatorUtil.checkFilter(paramArray)) {
            return;
        }
        super.enter(paramArray[0]);
    }

    public void leave(Object parameters) {
        Object[] paramArray = (Object[]) parameters;
        if (!AggregatorUtil.checkFilter(paramArray)) {
            return;
        }
        super.leave(paramArray[0]);
    }
}
